#include "install.h"
#include <QFileDialog>
#include <stdio.h>
#include <QMessageBox>
#include <QTextStream>

Install::Install(QWidget * parent):QWidget(parent)
{
	it=new InstallTool;
	it->setupUi(this);
	connect(it->install_path_pushButton,SIGNAL(released () ), this, SLOT(install_path_pushButton_cb()) );
	connect(it->bin_path_pushButton,SIGNAL(released () ), this, SLOT(bin_path_pushButton_cb()) );
	connect(it->help_path_pushButton,SIGNAL(released () ), this, SLOT(help_path_pushButton_cb()) );
	connect(it->qmake_pushButton,SIGNAL(released () ), this, SLOT(qmake_pushButton_cb()) );
	connect(it->cancel_pushButton,SIGNAL(released () ), this, SLOT(cancel_pushButton_cb()) );
	connect(it->scripts_pushButton,SIGNAL(released () ), this, SLOT(scripts_pushButton_cb()) );
	connect(it->compile_pushButton, SIGNAL(released () ), this, SLOT(compile_pushButton_cb()) );
	connect(it->compile_install_pushButton, SIGNAL(released () ), this, SLOT(compile_install_pushButton_cb()) );
}

void Install::install_path_pushButton_cb()
{

	QString s = QFileDialog::getExistingDirectory(
			this,
			"Choose a directory",
			"/home",
			QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
	
	if(s.isEmpty()) return;
	
	it->install_path_lineEdit->setText(s);
}

void Install::bin_path_pushButton_cb()
{

	QString s = QFileDialog::getExistingDirectory(
			this,
	"Choose a directory",
	"/home",
	QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
	
	if(s.isEmpty()) return;
	
	it->bin_path_lineEdit->setText(s);
}

void Install::qmake_pushButton_cb()
{

	QString s = QFileDialog::getOpenFileName(
			this,
	"Choose a file to open",
	"/home",
	"qmake (*)");
	
	if(s.isEmpty()) return;
	
	it->qmake_lineEdit->setText(s);
}

void Install::cancel_pushButton_cb()
{
	exit(0);
}


void Install::help_path_pushButton_cb()
{

	QString s = QFileDialog::getOpenFileName(
			this,
		"Choose a file to open",
		"/home",
		"Html File (*.html)");
	
	if(s.isEmpty()) return;
	
	it->help_path_lineEdit->setText(s);
}

void Install::scripts_pushButton_cb()
{
	build_scripts();
	QMessageBox::information (this, "Scripts builded", "compile.sh and install.sh has been done.\n Execute then for install.");
}

void Install::build_scripts()
{
	FILE *out=fopen("compile.sh","w");
	if(out==NULL)
	{
		printf("Error: compile.sh couldn't be written in disk.\n");
		QMessageBox::critical(this, "Error", "Error: compile.sh couldn't be written in disk.\n");
		return;
	}
	
	QString compile_sh;
	QString qmake=it->qmake_lineEdit->text();
	
	QTextStream sout(&compile_sh);
	
	sout << "cd qtoctave\n" << qmake << " -project\n";
	
	sout <<	qmake;
	if( ! it->install_path_lineEdit->text().isEmpty() )
	{
		sout << " \"DEFINES+=CONFIG_PATH=\\\"\\\\\\\"" << it->install_path_lineEdit->text() << "/\\\\\\\"\\\"\"";
		sout << " \"DEFINES+=ICON_PATH=\\\"\\\\\\\"" << it->install_path_lineEdit->text() << "/\\\\\\\"\\\"\"";
		sout << " \"DEFINES+=QTOCTAVE_HELP_PATH=\\\"\\\\\\\"" << it->install_path_lineEdit->text() << "/qtoctave_doc/index.html\\\\\\\"\\\"\"";
	}
	if( it->default_help_checkBox->isChecked() && ! it->help_path_lineEdit->text().isEmpty() )
	{
		sout << " \"DEFINES+=HELP_PATH=\\\"\\\\\\\"" << it->help_path_lineEdit->text() << "\\\\\\\"\\\"\"";
	}
	else
	{
		sout << " \"DEFINES+=HELP_PATH=\\\"\\\\\\\"" << it->install_path_lineEdit->text() << "/octave_doc/octave.html\\\\\\\"\\\"\"";
	}
	sout <<
		"\nmake\n"

		"cd ..\n"

		"cd widgetserver\n"

		<< qmake << " -project\n"
		<< qmake << "\n"
		
		<< "make\n"

		"cd ..\n";
	
	fprintf(out,compile_sh.toLocal8Bit().data());
	
	fclose(out);
	
	out=fopen("install.sh","w");
	if(out==NULL)
	{
		printf("Error: install.sh couldn't be written in disk.\n");
		QMessageBox::critical(this, "Error", "Error: install.sh couldn't be written in disk.\n");
		return;
	}
	
	QString install_sh;
	
	QTextStream iout(&install_sh);
	
	QString install_path( it->install_path_lineEdit->text() );
	
	iout << "cd qtoctave\n" "mkdir -p " << install_path << "/\n"

			<< "cp -Rv images " << install_path << "/\n"
			//<< "chmod +r " << install_path << "/images/*\n"
			
			<< "cp -Rv octave_doc qtoctave_doc  menus config.rc " << install_path << "/\n"
			//<< "chmod +r " << install_path << "/octave_doc/*\n"
			//<< "chmod +r " << install_path << "/qtoctave_doc/*\n"
			
			<< "cp qtoctave " << it->bin_path_lineEdit->text() << "/\n"
			<< "cd ..\n"

			<< "cp widgetserver/widgetserver " << it->bin_path_lineEdit->text() << "/\n"
			
			<< "cp -Rv widgetserver/doc/tutorial/html/*.html widgetserver/doc/tutorial/html/*.png " << install_path << "/qtoctave_doc/\n"

			<< "echo\n"
			"echo \"Escriba qtoctave, en un nuevo terminal, para iniciar la aplicacin.\"\n"
			"echo \"Please, write qtoctave for start.\"\n";
	
	fprintf(out,install_sh.toLocal8Bit().data());
	
	fclose(out);
}

void Install::compile_pushButton_cb()
{
	build_scripts();
	this->hide();
	system("sh compile.sh");
	this->show();
	printf("\nCompilation ended\n");
	//QMessageBox::information (this, "Compilation finished", "Execute install.sh for install.");
}

void Install::compile_install_pushButton_cb()
{
	build_scripts();
	this->hide();
	system("sh compile.sh");
	system("sh install.sh");
	this->show();
	printf("\nInstall ended\n");
	//QMessageBox::information (this, "Compilation finished", "Execute install.sh for install.");
}

